@@ -3,7 +3,7 @@
 import sys
 
 from circuits import Debugger
-from circuits.drivers import INotifyDriver
+from circuits.drivers._inotify import INotifyDriver
 
 driver = INotifyDriver() + Debugger()
 driver.add(sys.argv[1])
